
# The CLI to PixSoup service

[PixSoup](https://pixsoup.com) provides a simple interface to a cloud GPU where you can fine-tune
StableDiffusion using Dreambooth.

For integration with your own tooling check GraphQL [schema](schema.graphql).

## Usage

```bash
$ pixsoup --help
```

## Install

```bash
$ pip install pixsoup
```

## Build

```bash
$ python -m build
```